pub unsafe fn x264_encoder_open(arg1: *mut X264ParamT) -> *mut X264TExpand description
create a new encoder handler, all parameters from x264_param_t are copied
pub unsafe fn x264_encoder_open(arg1: *mut X264ParamT) -> *mut X264Tcreate a new encoder handler, all parameters from x264_param_t are copied