pub type X264ZoneT = x264_zone_t;Expand description
Zones: override ratecontrol or other options for specific sections of the video.
See x264_encoder_reconfig() for which options can be changed. If zones overlap, whichever comes later in the list takes precedence.
Aliased Type
struct X264ZoneT {
pub i_start: i32,
pub i_end: i32,
pub b_force_qp: i32,
pub i_qp: i32,
pub f_bitrate_factor: f32,
pub param: *mut x264_param_t,
}Fields
i_start: i32i_end: i32b_force_qp: i32i_qp: i32f_bitrate_factor: f32param: *mut x264_param_t